%define git      %{version}
%define gitparts b82c8c3abd9bca5d30a4d0c28fb4327ac38cf511

%define subrel 1
%define rel 1

Name:           fritzing
Version:        0.9.6
Release:        %mkrel %{rel}
Summary:        Electronic Design Automation software; from prototype to product
License:        GPLv3+, CC-BY-SA
Group:          Sciences/Other
Url:            http://fritzing.org
Source0:        https://github.com/fritzing/fritzing-app/archive/%{git}/%{name}-app-%{git}.tar.gz
# The fritzing-parts repository no longer uses git tags for marking releases.
# There is a "release_0.9.6" branch in the repository, though.
# Take the latest commit from that branch (as of 2021-02-17).
Source2:        https://github.com/fritzing/fritzing-parts/archive/%{gitparts}/%{name}-parts-%{gitparts}.tar.gz
# Taken from fedora until a fix for issue 3796
Source3:        parts.db
#TODO must be rediffed
#Patch0:         0000-disable-autoupdate.patch
# use system libgit2
Patch2:         fritzing-0.9.6-use-system-libgit2.patch
# some scripts are not yet ported to Python3 so let's patch them
Patch3:         fritzing-parts-0.9.6-port-remaining-of-the-scripts-to-python3.patch

BuildRequires:  pkgconfig(libgit2)
BuildRequires:  pkgconfig(minizip)
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Help)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5SerialPort)
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5WebKit)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  desktop-file-utils
BuildRequires:  boost-devel
BuildRequires:  quazip-devel
BuildRequires:  qttools5

# mga#24115
Requires:       qt5-database-plugin-sqlite

%description
Fritzing is an open-source initiative to support designers, artists,
researchers and hobbyists to take the step from physical prototyping
to actual product. It is in the spirit of Processing and Arduino which
allows users to document their Arduino and other electronic-based
prototypes, and to create a PCB layout for manufacturing.

%prep
%setup -q -n %{name}-app-%{git}
tar -xf %{SOURCE2}
mv %{name}-parts-%{gitparts}/ parts/

rm -f pri/quazip.pri
rm -rf src/lib/quazip

# Remove a <url> entry which causes the appstream file to fail validation.
sed -e '/<url type="forum">/d' -i 'org.fritzing.Fritzing.appdata.xml'

%autopatch -p1

%build
CXXFLAGS="%{optflags}"
%qmake_qt5 DEFINES=QUAZIP_INSTALLED
%make_build

# FIXME Generate the parts database
# https://github.com/fritzing/fritzing-app/issues/3796
#./Fritzing -platform minimal -f ./parts -db ./parts/parts.db

%install
%make_install INSTALL_ROOT=%{buildroot}

ln -s %{_bindir}/Fritzing %{buildroot}%{_bindir}/%{name}
cp -f %{buildroot}%{_mandir}/man1/Fritzing.1 %{buildroot}%{_mandir}/man1/fritzing.1

# FIXME Generate the parts database
install -m 0644 %{SOURCE3} %{buildroot}%{_datadir}/%{name}/parts/

%files
%doc README.md
%license LICENSE.GPL2 LICENSE.GPL3 LICENSE.CC-BY-SA
%{_bindir}/Fritzing
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/org.%{name}.Fritzing.desktop
%{_metainfodir}/org.%{name}.Fritzing.appdata.xml
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/mime/packages/%{name}.xml
%{_mandir}/man?/*


%changelog
* Sun Mar 19 2023 daviddavid <daviddavid> 0.9.6-1.1.mga8
+ Revision: 1949675
- workaround the parts.db file until an upstream fix
- new version: 0.9.6 (fixes mga#18689)
- drop quazip5 patch (build against system quazip library - now supported upstream)
- rebase libgit2 and port-remaining-of-the-scripts-to-python3 patches

* Wed Dec 30 2020 luigiwalser <luigiwalser> 0.9.4-4.git20191201.mga8
+ Revision: 1666238
- rebuild for libgit2

* Wed Dec 16 2020 umeabot <umeabot> 0.9.4-3.git20191201.mga8
+ Revision: 1658485
- Rebuild for new Qt5

* Fri Jul 24 2020 daviddavid <daviddavid> 0.9.4-2.git20191201.mga8
+ Revision: 1608631
- rebuild for new libgit2 1.0.1
- add support for libgit2 >= 1.0

* Wed Feb 19 2020 daviddavid <daviddavid> 0.9.4-1.git20191201.mga8
+ Revision: 1544395
- new version: 0.9.4 (CD-498)
- remove merged upstream patches
- add patch to port remaining of the scripts to python3
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Mon May 06 2019 alexl <alexl> 0.9.3b-6.git20181017.mga7
+ Revision: 1396417
- fix desktop file
- update Russian translation

* Sat Apr 20 2019 wally <wally> 0.9.3b-5.git20181017.mga7
+ Revision: 1393750
- rebuild for libgit2 0.28.1

* Sat Mar 30 2019 umeabot <umeabot> 0.9.3b-4.git20181017.mga7
+ Revision: 1381787
- Qt5 Rebuild

* Wed Jan 02 2019 daviddavid <daviddavid> 0.9.3b-3.git20181017.mga7
+ Revision: 1348742
- add patch to fix the logic to find the parts directory (mga#24114)

* Wed Jan 02 2019 daviddavid <daviddavid> 0.9.3b-2.git20181017.mga7
+ Revision: 1348730
- add missing dependency on qt5-database-plugin-sqlite (mga#24115)

* Wed Oct 17 2018 zezinho <zezinho> 0.9.3b-1.git20181017.mga7
+ Revision: 1321869
- shorter release

* Wed Oct 17 2018 zezinho <zezinho> 0.9.3b-0.git624187517fc89062a4e83d6c08d306863c0d4ec7.mga7
+ Revision: 1321496
- no release since 2016 so new version from today git 624187517fc89062a4e83d6c08d306863c0d4ec7

* Sun Sep 23 2018 umeabot <umeabot> 0.9.2-0.beta20150403.9.mga7
+ Revision: 1297787
- Mageia 7 Mass Rebuild

* Mon May 09 2016 luigiwalser <luigiwalser> 0.9.2-0.beta20150403.8.mga6
+ Revision: 1011760
- add patch from fedora to fix build with quazip
- use upstream .desktop file
- rebuild for quazip

* Sun Feb 14 2016 umeabot <umeabot> 0.9.2-0.beta20150403.7.mga6
+ Revision: 960196
- Mageia 6 Mass Rebuild

* Sat Jul 04 2015 alexl <alexl> 0.9.2-0.beta20150403.6.mga6
+ Revision: 849903
- enable external quazip (thanks to anaselli for fix)

* Fri Jul 03 2015 alexl <alexl> 0.9.2-0.beta20150403.5.mga6
+ Revision: 849760
- version 0.9.2b
- switch to qt5
- disable external quazip because of segfaults with open/save
- add additional fritzing man page
- update disable-autoupdate.patch

* Tue Jan 06 2015 alexl <alexl> 0.8.7-0.beta20140124.4.mga5
+ Revision: 808817
- changed GenericName in desktop file

* Wed Oct 15 2014 umeabot <umeabot> 0.8.7-0.beta20140124.3.mga5
+ Revision: 749053
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.8.7-0.beta20140124.2.mga5
+ Revision: 679360
- Mageia 5 Mass Rebuild

* Mon Apr 14 2014 alexl <alexl> 0.8.7-0.beta20140124.1.mga5
+ Revision: 613998
- imported package fritzing

